<?php

	///////////////////////////////////////////////////////////////////////////////////////////////////
	//purchase confirmation mail with download link 
	
	//the last thing you want with digital products is a customer purchasing and not reaching the download page
	//because of "http request was reset" or a similar error. 
	//Therefore, because we already have his email we will send download link to the customer via that email.

	//automatic optin confirmation email
	
	//While there will be customers who visit the site once and that's it, there will be also customer interested
	//in upgrades, software patches, spare parts (for physical products), related products (say a new "live 
	//concert recording became available for my favorite band" notification and so on. We will give the customer
	//a possibility to opt-in for such notification.
	
	//our approach is to combine the two emails into one, the less email I receive the better and I hope that's 
	//true for all the customers.   
	///////////////////////////////////////////////////////////////////////////////////////////////////

	global $wpdb;
	
	//the autoresponder plugin data model is starting at the subscription form.
	//the form determines which newsletter (and optionally autoresponder) is subscribed.
	//it also defines the subscription confirmation emails. We will use the confirmation email 
	//to deliver the digital content download link for the digital product sold and allow 
	//the user to subscribe for updates if he wishes to do so.
	
	/////// Default setup ///////
	
	//get the default form (confirmation email templates) we will be using if there is no product match
	$fid = get_option('EVI_Customer_List_Form_ID');
	
	//get the default autoresponder we will be subscribing to if there is no product match
	$responder = get_option('EVI_Customer_List_Autoresponder_ID');

	//get the email and customer initials from the paypal IPN call
	$email = wpr_sanitize($_POST['payer_email']);
	$name = wpr_sanitize($_POST['first_name']).' '.wpr_sanitize($_POST['last_name']);

	/////// Product specific setup ///////
	
	//TODO: not sure if this is and will be unique, so maybe later pick another (more unique) attribute
	//for the moment include in documentation that we expect it is
	$productSold = wpr_sanitize($_POST['item_name']);
    //$productSold = wpr_sanitize($_POST['item_name1']);

	//get a product specific newsletter if it was configured for this product instead of using the default newsletter
	$result = $wpdb->get_results("select * from ".$wpdb->prefix."EVI_PRODUCTS where item_name='$productSold'");
	if (count($result))
	{
		//there is a product specific configuration, we will use this one rather than the default
		
		//Each digital product has a different download link, so you will need a different email (with only that link) per product;
		//we have a subscription form defined per product; get subscription form id, 
		//the form defines the subscrption confirmation email, newsletter and the download link. 
		$fid = $result[0]->fid;

		$responder = $result[0]->aid;
	}

	$newsletter = NewsletterForForm($fid);

	//say you want to have a customer satisfaction form sent to the customer two weeks after purchase 
	//(and certainly only if they confirmed they are willing to do that in the first confirmation email)
	
	//the best way would be an autoresponder
	$followup = null;
	
	//autoresponder attached to a product?
	if($responder != null && $responder != 0)  //otherwise, no autoresponder will be used
	{
		$followup = "autoresponder";
	}

	//if no newsletter configured or newsletter suppressed for this product, don't send any emails	
	//otherwise, send the confirmation email with download link
	
	//currently the autoresponder plugin from Raj does not support autoresponder without a newsletter
	//so it is sufficient to check only for newsletter here
	if($newsletter != null)
	{
		EVI_Send_Optin_Verification_Email($name,$email,$followup,$newsletter,$responder,$fid);
	}

	//save information about the product the customer purchased
	$track_Sales = get_option('EVI_Track_Sales') != '' ? get_option('EVI_Track_Sales') : '0';
	if($track_Sales == '1')
	{
		$txn_id = wpr_sanitize($_POST['txn_id']);
		$price = wpr_sanitize($_POST['mc_gross_1']);
		$currency = wpr_sanitize($_POST['mc_currency']);
		$exchange_rate = wpr_sanitize($_POST['exchange_rate']);
		if(	$exchange_rate == 0)	
			$exchange_rate = 1; //if USD conversion rate is 1:1

		$query = "INSERT INTO ".$wpdb->prefix."EVI_SALES_MADE "."(item_name, 	   name,	email,   txn_id,	currency,	exchange_rate,	price)".
										" values ('$productSold', '$name', '$email','$txn_id', '$currency', '$exchange_rate', '$price');";
		$wpdb->query($query);
	}
						
	//done

	function NewsletterForForm($fid)
	{
		global $wpdb;

		if($fid != 0)   //no subscription at all is a valid option
		{
			//a form is directly attached to a newsletter, so get it from there
			$result = $wpdb->get_results("select * from ".$wpdb->prefix."wpr_subscription_form where id = $fid");
			if (count($result)) //otherwise something went wrong
			{
				//get the default newsletter we will be subscribing to if there is no product match
				return $result[0]->nid;
			}
		}
		return null;
	}

	//this is more or less a copy from wpautoresponder plugin, will negotiate with Raj to make this a function in his plugin later on
	function EVI_Send_Optin_Verification_Email ($name,$email,$followup,$newsletter,$responder,$fid)
	{
		global $wpdb;
		$skiplist = array("name","email","followup","blogsubscription","cat","return_url","responder");
	
		$query = "SELECT count(*) count FROM ".$wpdb->prefix."wpr_newsletters where id=$newsletter";	
		$results = $wpdb->get_results($query);	
		$count = $results[0]->count;	
		if ($count == 0)
		{  
			return;
			error("The newsletter to which you are trying to subscribe doesn't exist in our records.");
		}

		if (!empty($followup) && !in_array($followup,array("autoresponder","postseries")))
		{
			return;
			error('The form you filled out is coded improperly. The followup subscription hidden fields did not have a valid value.');
			exit;
		}

		if (empty($name))
		{
			return;
			error('You have not filled the name field in the subscription form. Please <a href="javascript:window.history.go(-1);">go back</a> and enter your name in the name field.');
		}

		//start validations

		if (!validateEmail($email))   //the expression is just for now.
		{
			return;
			error('<center><div style="font-size: 20px;">Invalid Email Address</div></center> The e-mail address you mentioned is not a valid e-mail address. Please <a href="javascript:window.history.go(-1);">go back</a> and re-enter the e-mail in the correct format.');
		}
		
		$errors = array();
		
		$errors = apply_filters("_wpr_subscriptionform_validate",$errors);
		
		if (count($errors) !=0)
		{
			return;
			$errorString = implode("<li>",$errors);
			error("<ol>$errorString</ol>");
		}


		if (!empty($followup) && !empty($responder))
		{
			switch ($followup)
			{
				case 'postseries':

					$query = "SELECT COUNT(*) count FROM ".$wpdb->prefix."wpr_blog_series where id=".$responder;
					$items = $wpdb->get_results($query);
					$count = $items[0]->count;

					if ($count == 0)
					{
						return;
						error("There was a problem while processing your subscription request. The postseries you have subscribed to doesn't exist in our records. The post series you have subscribed to doesn't exist and/or may have been deleted by the site administrator. The site owner has been notified of the problem.");
						wpr_error("$name ($email) tried to subscribe to a non-existent postseries (of id $responder) that doesn't exist from ".$_SERVER['HTTP_REFERER']);
					}

					break;

				case 'autoresponder':
					$query = "SELECT COUNT(*) count FROM ".$wpdb->prefix."wpr_autoresponders where id=".$responder;
					$items = $wpdb->get_results($query);
					$count = $items[0]->count;
					if ($count == 0)
					{
						return;
						error("There was a problem while processing your subscription. The follow-up series you have subscribed to doesn't exist in our records. The site administrator has been notified of the problem.");
						wpr_error("$name ($email) tried to subscribe to autoresponder ( of id$responder) that doesn't exist from ".$_SERVER['HTTP_REFERER']);
					}

					break;

				default:
					return;
					print "Error! The form is badly formed. ";
					exit;
			}
		}

		if ($bsubscription == "cat")
		{
			$category = get_category($bcategory);

			if (empty($category))
			{
				return;
				error("The was a problem when processing your subscription. The content to which you are trying to subscribe doesn't exist. It may have been deleted by the site administrator. The site administrator has been notified of the problem.");
				wpr_error("$name ($email) tried to subscribe to a blog category ($bcategory) that doesn't exist from ".$_SERVER['REQUEST_URI']);
			}
		}

		$newsletter = _wpr_newsletter_get($newsletter);

		$nid = $newsletter->id;
	
		$hash = _wpr_subscriber_hash_generate();

		$query = "SELECT * FROM ".$wpdb->prefix."wpr_subscribers where email='$email' and nid='$nid';";
		$subscribeList = $wpdb->get_results($query);
		
		$zone = date_default_timezone_get();
		date_default_timezone_set("UTC");
		if (count($subscribeList) ==0)  //the visitor is a new subscriber
		{
			//new subscriber, add him to records
		
			$date = time();
			$query = "INSERT INTO ".$wpdb->prefix."wpr_subscribers (nid,name,email,date,active,fid,hash) values ('$nid','$name','$email','$date',1,'$fid','$hash');";
			$wpdb->query($query);
			//now get the subscriber object 
			$query = "SELECT * FROM ".$wpdb->prefix."wpr_subscribers where email='$email' and nid='$nid';";
			$subscriber = $wpdb->get_results($query);
			$subscriber = $subscriber[0];
		}
		else   //the subscriber already exists
		{
			//find if the subscriber had already subscribed before and is still subscribed.
			$query = "select * from ".$wpdb->prefix."wpr_subscribers where active=1 and confirmed=1 and email='$email' and nid='$nid'; ";
			$results = $wpdb->get_results($query);

			if (count($results) >0)
			{
				return;
 				error("You are already subscribed to this newsletter.");
			}
			else
			{
				$subscriber = $subscribeList[0];		 
				$date = time();
				$query = "update ".$wpdb->prefix."wpr_subscribers set active=1, confirmed=0, date='$date' where email='$email' and nid='$nid';";
   				$wpdb->get_results($query);
			}
		}
		$id = intval($subscriber->id);
		
		//insert the subscriber's custom field values
		foreach ($_POST as $field_name=>$value)
		{
			if (ereg('cus_.*',$field_name))
			{
				$name = base64_decode(str_replace("cus_","",$field_name));
				$query = "select * from ".$wpdb->prefix."wpr_custom_fields where name='$name' and nid='$nid'";
				$custom_fields = $wpdb->get_results($query);
				$custom_fields = $custom_fields[0];
				$cid = $custom_fields->id;
				$value = $_POST[$field_name];
				$query = "DELETE FROM ".$wpdb->prefix."wpr_custom_fields_values WHERE nid=$nid and sid=$id and cid=$cid";			
				$wpdb->query($query);
				$query = "INSERT INTO ".$wpdb->prefix."wpr_custom_fields_values (nid,sid,cid,value)  values ('$nid','$id','$cid','$value');";
				$wpdb->query($query);
			}

			//sparing the inserted values, insert null for the rest of the custom fields defined for this newslette					 
		}

		//what custom fields already exist? so that we dont try to insert duplicate values for those
		$query = "SELECT b.name name from ".$wpdb->prefix."wpr_custom_fields_values a, ".$wpdb->prefix."wpr_custom_fields b where a.sid=$id and b.id=a.cid;";
		$fields = $wpdb->get_results($query);

		if (count ($fields) > 0)
		{
			foreach ($fields as $field)
			{
				$existing[] = $field->name;
			}
		}

		if (count($existing) != 0)
			$notin = implode("','",$existing);
		else
			$notin ="";

		$notin = "IN('".$notin."')";
		$query = "SELECT * FROM ".$wpdb->prefix."wpr_custom_fields WHERE `name` NOT $notin AND nid='$nid'";
		$otherfields = $wpdb->get_results($query);

		foreach ($otherfields as $field)
		{
			$cid  = $field->id;
			$query = "INSERT INTO ".$wpdb->prefix."wpr_custom_fields_values (nid,sid,cid,value) VALUES ('$nid','$id','$cid','');";
			$wpdb->query($query);
		}

		if ($followup)
		{
			$query = "SELECT a.* FROM ".$wpdb->prefix."wpr_followup_subscriptions a, ".$wpdb->prefix."wpr_subscribers b where a.sid=b.id and a.type='$type' and a.eid='$responder' and b.id='$id'";
			$subscriptions = $wpdb->get_results($query);

			//subscribe to autoresponder only if they aren't or ever haven't subscribed to this newsletter
			if (count($subscriptions) == 0)
			{
				$date = time();
				$query = "DELETE FROM ".$wpdb->prefix."wpr_followup_subscriptions where sid=$id and type='$followup' and eid='$responder';";
				$wpdb->query($query);
				$query = "INSERT INTO ".$wpdb->prefix."wpr_followup_subscriptions (sid,type,eid,sequence,doc) values ('$id','$followup','$responder',-1,$date);";
				$wpdb->query($query);
			}
		}

		//if blog subscription is mentioned in the form
		if (!empty($bsubscription))
		{
			$deleteExistingSubscriptionQuery = sprintf("DELETE FROM %swpr_blog_subscripition WHERE sid=%d, type='%s',catid=%d",$wpdb->prefix,$id,$bsubscription,$bcategory);
			$wpdb->query($deleteExistingSubscriptionQuery);
			$timeNow = time();
			$query = "INSERT INTO ".$wpdb->prefix."wpr_blog_subscription (sid,type,catid, last_published_post_date) values ('$id','$bsubscription','$bcategory','$timeNow');";
			$wpdb->query($query);
		}	

		if (!empty($fid) && $fid != 0)
		{
			$query = "SELECT * from ".$wpdb->prefix."wpr_subscription_form where id='$fid'";
			$theForm = $wpdb->get_results($query);
			if (count($theForm) != 0)
			{
				$theForm = $theForm[0];
				$confirm_subject = $theForm->confirm_subject;
				$confirm_body = $theForm->confirm_body;
			}		
		}
	
		$theqstring = $subscriber->id."%%".$subscriber->hash."%%".$fid;
		$p = trim(base64_encode($theqstring),"=");
		$link = get_bloginfo("siteurl")."/?wpr-confirm=".$p;
	
		$dirname = str_replace("enroll-via-ipn/EVI_register_customer.php","",__FILE__);
		echo($dirname );
		echo($dirname."wp-responder-email-autoresponder-and-newsletter-plugin/templates/confirm.txt" );
		$confirm = file_get_contents($dirname."wp-responder-email-autoresponder-and-newsletter-plugin/templates/confirm.txt");
		$confirm = str_replace("[!confirm_link!]",$link,$confirm);

		$newsletter = _wpr_newsletter_get($nid);
		$newslettername = $newsletter->name;
		$url = ($_SERVER['HTTP_REFERER'])?$_SERVER['HTTP_REFERER']:"Unknown";
		$ip = $_SERVER['REMOTE_ADDR'];
		$date = "At ".date("g:i dS M, Y");

		$address = get_option('wpr_address');

		$confirm_subject = str_replace("[!ipaddress!]",$ip,$confirm_subject);
		$confirm_body = str_replace("[!ipaddress!]",$ip,$confirm_body);
		$confirm_subject = str_replace("[!date!]",$date,$confirm_subject);
		$confirm_body = str_replace("[!date!]",$date,$confirm_body);

		$confirm_subject = str_replace("[!url!]",$url,$confirm_subject);

		$confirm_body = str_replace("[!url!]",$url,$confirm_body);

		$confirm_subject = str_replace("[!newslettername!]",$newslettername,$confirm_subject);
		$confirm_body = str_replace("[!newslettername!]",$newslettername,$confirm_body);

		$confirm_subject = str_replace("[!address!]",$address,$confirm_subject);
		$confirm_body = str_replace("[!address!]",$address,$confirm_body);
		$confirm_body = str_replace("[!confirm!]",$confirm,$confirm_body);
		$additional_parameters = array(
										"ipaddress" => $_SERVER['REMOTE_ADDR'],
										"date"	 => date("g:i d F Y",time()),
										"url"	  => $_SERVER['HTTP_REFERER']
									   );
		$params = array();
	
		date_default_timezone_set($zone);
	
		$params[0] = $confirm_subject;
		$params[1] = $confirm_body;
		wpr_create_temporary_tables($nid);	
		wpr_make_subscriber_temptable($nid);
		wpr_place_tags($id,$params,$additional_parameters);
		$from_email = $newsletter->fromemail;
	
		if (!$from_email)	
			$from_email = get_bloginfo("admin_email");	

		$from_name = $newsletter->fromname;
	
		if (!$from_name)
			$from_name = get_bloginfo("name");

		$subject = $params[0];
		$body = $params[1];
	
		$verificationEmail = array(
									'to'=>$email,
									'subject'=>$subject,
									'textbody'=>$body,
									'fromname'=>$from_name,
									'from'=>$from_email
								);
							
		@dispatchEmail($verificationEmail);
	}
?>