<?php
	/*
	Plugin Name: Enroll via IPN
	Plugin URI: http://EVI.brickmiracles.com/
	Description: Enrolls purchasing cutomers into a customer list via paypal IPN and automatically registers sales made.
	Version: 1.0.0.3
	Author: Julius Uhrik 
	Based on projects:
		1) EPT by Juergen Schulze, 1manfactory@gmail.com, http://1manfactory.com/ept
		2) PayPal IPN Listener by Micah Carrick, https://github.com/Quixotix/PHP-PayPal-IPN
		3) WP Autoresponder by Raj Sekharan, http://www.wpresponder.com

	Author URI: http://EVI.brickmiracles.com/
	License: GPL2
	*/

	/*  Copyright 2011  Julius Uhrik  (email : the same with a dot between @gmail.com)

		This program is free software; you can redistribute it and/or modify
		it under the terms of the GNU General Public License, version 2, as 
		published by the Free Software Foundation.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program; if not, write to the Free Software
		Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
	*/
?>
<?php

	define( 'EVI_PUGIN_NAME', 'EVI');
	define( 'EVI_PLUGIN_DIRECTORY', 'enroll-via-ipn');
	define( 'EVI_CURRENT_VERSION', '1.0.0.3' );
	define( 'EVI_CURRENT_BUILD', '1' );
	define( 'EVI_LOGPATH', str_replace('\\', '/', WP_CONTENT_DIR).'/evi-logs/');
	define( 'EVI_DEBUG', false);		# never use debug mode on productive systems

	//i18n plugin domain for language files
	define( 'EMU2_I18N_DOMAIN', 'EVI' );

	//how to handle log files, don't load them if you don't log
	//require_once('EVI_logfilehandling.php');

	//load language files
	function EVI_set_lang_file() {
		# set the language file
		$currentLocale = get_locale();
		if(!empty($currentLocale)) {
			$moFile = dirname(__FILE__) . "/lang/" . $currentLocale . ".mo";
			if (@file_exists($moFile) && is_readable($moFile)) {
				load_textdomain(EMU2_I18N_DOMAIN, $moFile);
			}
		}
	}

	EVI_set_lang_file();

	//create custom plugin settings menu
	add_action( 'admin_menu', 'EVI_create_menu' );

	//call register settings function
	add_action( 'admin_init', 'EVI_register_settings' );

	register_activation_hook(__FILE__, 'EVI_activate');
	register_deactivation_hook(__FILE__, 'EVI_deactivate');
	register_uninstall_hook(__FILE__, 'EVI_uninstall');

	add_action( 'template_redirect', 'EVI_queryVarsListener' );
	add_filter( 'query_vars',  'addIPNQueryVar' );

	function addIPNQueryVar($public_query_vars) {
		$public_query_vars[] = 'ipn';
		return $public_query_vars;
	}

	function EVI_queryVarsListener() {
		//Check that the query var is set and is the correct value.
		if (isset($_GET['ipn']) && $_GET['ipn'] == 1)
		{
			require "ipn.php";

			//Stop WordPress entirely
			exit;
		}
	}

	//activating the default values
	function EVI_activate() {
		//add_option('EVI_PayPal_Seller_Email', 'enter your primary paypal email here');
	}

	//deactivating
	function EVI_deactivate() {
		//do your deactivate things here (like deleting options if necessary), for example:
		//delete_option('EVI_PayPal_Seller_Email');
	}

	//uninstalling
	function EVI_uninstall() {
	
		# delete all data stored
		//TODO: we might want to do the rest, but in case of reinstall, it would be lost, right?
		//We'd only delete those which store a lot of data (and we don't have those)
		//delete_option('EVI_PayPal_Seller_Email'); ...

		//delete log files and folder only if needed
		if (function_exists('EVI_deleteLogFolder')) 
			EVI_deleteLogFolder();
	}

	function EVI_create_menu() {

		//create new top-level menu (Dashboard->Enroll via IPN and Dashboard->Enroll via IPN->Enroll via IPN)
		add_menu_page( 
			__('Enroll via IPN', EMU2_I18N_DOMAIN),
			__('Enroll via IPN', EMU2_I18N_DOMAIN),
			0,
			EVI_PLUGIN_DIRECTORY.'/EVI_setup.php',
			'',
			plugins_url('/images/enroll_via_ipn_16x16.png', __FILE__)
		);

		//(Dashboard->Enroll via IPN->Products sold)
		add_submenu_page( 
			EVI_PLUGIN_DIRECTORY.'/EVI_setup.php',
			__('Products', EMU2_I18N_DOMAIN),
			__('Products', EMU2_I18N_DOMAIN),
			9,
			EVI_PLUGIN_DIRECTORY.'/EVI_products_setup.php'
		);
		//(Dashboard->Enroll via IPN->Products sold)
		add_submenu_page( 
			EVI_PLUGIN_DIRECTORY.'/EVI_setup.php',
			__('Products sold', EMU2_I18N_DOMAIN),
			__('Products sold', EMU2_I18N_DOMAIN),
			9,
			EVI_PLUGIN_DIRECTORY.'/EVI_products_sold.php'
		);
	}


	function EVI_register_settings() {
		//register settings
		register_setting( 'EVI-settings-group', 'EVI_Paypal_Seller_email' );
		register_setting( 'EVI-settings-group', 'EVI_Notification_email' );
		register_setting( 'EVI-settings-group', 'EVI_Notify_On_Valid_IPN' );
		register_setting( 'EVI-settings-group', 'EVI_Track_Sales' );
		register_setting( 'EVI-settings-group', 'EVI_Customer_List_Autoresponder_ID' );
		register_setting( 'EVI-settings-group', 'EVI_Customer_List_Form_ID' );		
	}

	//check if debug is activated
	function EVI_debug() {
		# only run debug on localhost
		if ($_SERVER["HTTP_HOST"]=="localhost" && defined('EPS_DEBUG') && EPS_DEBUG==true) return true;
	}
?>
