<?php
	/**
	 *  PHP-PayPal-IPN Handler
	 */
 
	/*NOTE: the IPN call is asynchronous and can arrive later than the browser is redirected to the success url by paypal
	You cannot rely on setting up some details here and then using them in your success page.
	*/

	ini_set('log_errors', true);
	ini_set('error_log', dirname(__FILE__).'/ipn_errors.log');

	include('ipnlistener.php');
	$listener = new IpnListener();

	/*While testing your IPN script you should be using a PayPal "Sandbox" (get an account at: https://developer.paypal.com )
	When you are ready to go live change use_sandbox to false.*/

	//$listener->use_sandbox = true;

	try {
		$listener->requirePostMethod();
		$verified = $listener->processIpn();
	} catch (Exception $e) {
		error_log($e->getMessage());
		exit(0);
	}

	$YOUR_NOTIFICATION_EMAIL_ADDRESS=get_option('EVI_Notification_email');

	/*The processIpn() method returned true if the IPN was "VERIFIED" and false if it was "INVALID".*/

	if ($verified) {

		/*	Once you have a verified IPN you need to do a few more checks on the POST
		fields--typically against data you stored in your database during when the
		end user made a purchase (such as in the "success" page on a web payments
		standard button). The fields PayPal recommends checking are:	
			1. Check the $_POST['payment_status'] is "Completed"
			2. Check that $_POST['txn_id'] has not been previously processed 
			3. Check that $_POST['receiver_email'] is get_option('EVI_Paypal_Seller_email')
			4. Check that $_POST['payment_amount'] and $_POST['payment_currency'] 
				are correct
		*/

		//note: This is just notification for us. Paypal has already made up its mind and the payment has been processed 
		//  (you can't cancel that here)
		if( $_POST['receiver_email'] != get_option('EVI_Paypal_Seller_email'))
		{
			if($YOUR_NOTIFICATION_EMAIL_ADDRESS !='')
			{	
				mail($YOUR_NOTIFICATION_EMAIL_ADDRESS, 'Warning: IPN with invalid receiver email!', $listener->getTextReport());	
			}
			else
			{
				error_log('notification email not set');
			}
		}

		if($_POST['payment_status'] == "Completed")
		{
			//a customer has purchased from this website
			//add him to database for customer support
			
			require "EVI_register_customer.php";
		}

		$notifyOnValid = get_option('EVI_Notify_On_Valid_IPN')!= '' ? get_option('EVI_Notify_On_Valid_IPN') : '0';
		if($notifyOnValid == '1')
		{
			mail($YOUR_NOTIFICATION_EMAIL_ADDRESS, 'Verified IPN', $listener->getTextReport());
		}

	} else {
		/*An Invalid IPN *may* be caused by a fraudulent transaction attempt. It's a good idea to have a developer or sys admin 
		manually investigate any invalid IPN.*/

		mail($YOUR_NOTIFICATION_EMAIL_ADDRESS, 'Invalid IPN', $listener->getTextReport());
	}

	//we're done here
?>